carousel_custom_slider library

Classes

AnimatedBuilderSettings
Class to hold settings for the AnimatedBuilder widget.
AnimatedSmoothIndicator
Unlike SmoothPageIndicator this indicator is self-animated and it only needs to know active index
BasicIndicatorEffect
Basic implementation of IndicatorEffect that holds some shared properties and behaviors between different effects
BasicIndicatorPainter
Basic implementation of IndicatorPainter that holds some shared properties and behaviors between different painters
Carousel3D
A 3D rotating carousel without a shader mask.
Carousel3DAlt
An alternate 3D rotating carousel with smaller cards and a closer camera.
Carousel3DShader
A 3D rotating carousel with a full-screen lateral fade applied via ShaderMask.
CarouselConfig
Configuration shared across all carousel 3D variants.
CarouselCustomSlider
A customizable carousel widget that displays a list of images or other content in a horizontally or vertically scrolling list.
ColorTransitionEffect
Holds painting configuration to be used by TransitionPainter
CoverflowCarousel
A coverflow-style carousel with a real 3-D Y-axis rotation effect.
CoverflowItem
Holds the data for a single coverflow carousel card.
CustomizableEffect
Holds painting configuration to be used by CustomizablePainter
DefaultIndicatorColors
Holds theme-derived default colors for the indicator
DotBorder
Holds dot-border painting specs
DotDecoration
Holds dot painting specs
ExpandingDotsEffect
Holds painting configuration to be used by ExpandingDotsPainter
IndicatorEffect
An Abstraction for a dot-indicator animation effect
IndicatorPainter
A basic abstract implementation of customPainter to avoid overriding shouldRepaint in every painter
JumpingDotEffect
Holds painting configuration to be used by JumpingDotPainter
ScaleEffect
Holds painting configuration to be used by ScalePainter
ScrollingDotsEffect
Holds painting configuration to be used by ScrollingDotsPainter or ScrollingDotsWithFixedCenterPainter
SlideEffect
Holds painting configuration to be used by SlidePainter
SmoothIndicator
Draws dot-ish representation of pages by the number of count and animates the active page using offset
SmoothPageIndicator
A widget that draws a representation of pages count Inside of a PageView
SmoothPageIndicatorTheme
A ThemeExtension that provides default configuration for SmoothPageIndicator and AnimatedSmoothIndicator widgets.
SwapEffect
Holds painting configuration to be used by SwapPainter
WheelGallery
A circular wheel gallery with scroll-driven animation.
WheelGalleryItem
A single item in WheelGallery.
WormEffect
Holds painting configuration to be used by WormPainter

Enums

AnimatedBuilderType
Carousel3DType
The style/type of the 3D ring carousel.
DotBorderType
The variants of dot borders
SlideType
The Slide effect variants
SwapType
The swap effect variants
TransformType
TransformType3d
WormType
The Worm effect variants

Extensions

UnsplashUrl on String
Convenience extension for building a network URL from an Unsplash photo ID.

Constants

kDefaultUnsplashIds → const List<String>
Default Unsplash photo IDs bundled with the package for demo/example use.

Functions

buildCarousel3dError(double width, double height) Widget
Builds the error widget used by every carousel variant.
buildCarousel3dPlaceholder(double width, double height) Widget
Builds the loading placeholder widget used by every carousel variant.

Typedefs

ColorBuilder = Color Function(int index)
Signature for a function that returns color for each index
OnDotClicked = void Function(int index)
Signature for a callback function used to report dot tap-events