WormEffect class
Holds painting configuration to be used by WormPainter
- Inheritance
-
- Object
- IndicatorEffect
- BasicIndicatorEffect
- WormEffect
Constructors
Properties
- activeDotColor → Color?
-
The active dot color
If null, defaults to the app's primary color
finalinherited
- dotColor → Color?
-
Inactive dots color or all dots in some effects
If null, defaults to the app's primary color with reduced opacity
finalinherited
- dotHeight → double
-
Singe dot height
finalinherited
- dotWidth → double
-
Singe dot width
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- paintStyle → PaintingStyle
-
Inactive dots paint style (fill|stroke) defaults to fill.
finalinherited
- radius → double
-
Single dot radius
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
The horizontal space between dots
finalinherited
- strokeWidth → double
-
This is ignored if paintStyle is PaintStyle.fill
finalinherited
- type → WormType
-
The effect variant
final
Methods
-
buildPainter(
int count, double offset, DefaultIndicatorColors indicatorColors) → IndicatorPainter -
Builds a new painter every time the page offset changes
override
-
calculateSize(
int count) → Size -
Calculates the size of canvas based on
dots count, size and spacing
inherited
-
hitTestDots(
double dx, int count, double current) → int -
Returns the index of the section that contains
dx.inherited -
lerp(
covariant WormEffect? other, double t) → WormEffect -
Linearly interpolates between two effects.
Returns
thisifotheris null or not the same type.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited